==> plasma-framework-5.27.80.tar.xz: plasma-framework-5.27.80/src/desktoptheme/breeze/metadata.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "kde-artists@kde.org",
                "Name": "KDE Visual Design Group",
                "Name[ar]": "مجموعة التصميم المرئي لكِيدِي",
                "Name[az]": "KDE Vizual Dizayn Qrupu",
                "Name[be]": "Суполка візуальнага дызайну KDE",
                "Name[bg]": "KDE Visual Design Group",
                "Name[ca@valencia]": "Grup de disseny visual de KDE",
                "Name[ca]": "Grup de disseny visual de KDE",
                "Name[cs]": "Skupina vizuálního návrhu KDE",
                "Name[de]": "KDE Visual Design Group",
                "Name[en_GB]": "KDE Visual Design Group",
                "Name[eo]": "KDE Vida Dezajna Grupo",
                "Name[es]": "El grupo de diseño visual de KDE",
                "Name[eu]": "KDE Diseinu bisualeko taldea",
                "Name[fi]": "KDE:n visuaalinen suunnitteluryhmä",
                "Name[fr]": "Groupe de conception graphique de KDE « VDG » (Visual Design Group)",
                "Name[gl]": "Grupo de deseño visual de KDE",
                "Name[he]": "קבוצת העיצוב החזותי של KDE",
                "Name[ia]": "KDE Visual Design Group (Gruppo de Designo Visual de KDE)",
                "Name[id]": "Grup Desain Visual KDE",
                "Name[it]": "KDE Visual Design Group",
                "Name[ka]": "KDE Visual Design Group",
                "Name[ko]": "KDE 시각 디자인 그룹",
                "Name[nl]": "KDE Visuele ontwerpgroep",
                "Name[nn]": "KDE Visual Design Group",
                "Name[pl]": "Grupa oprawy graficznej KDE",
                "Name[pt]": "Grupo de Desenho Visual do KDE",
                "Name[pt_BR]": "Grupo de design visual do KDE (KDE VDG)",
                "Name[ru]": "Группа KDE Visual Design",
                "Name[sa]": "KDE Visual Design Group",
                "Name[sk]": "KDE Visual Design Group",
                "Name[sl]": "Skupina vizualnega designa KDE",
                "Name[sv]": "KDE:s visuella designgrupp",
                "Name[ta]": "கே.டீ.யீ. வரைகலை வடிவமைப்புக் குழு",
                "Name[tr]": "KDE Görsel Tasarım Grubu",
                "Name[uk]": "Група з візуального дизайну KDE",
                "Name[vi]": "Đội Thiết kế Trực quan KDE",
                "Name[x-test]": "xxKDE Visual Design Groupxx",
                "Name[zh_CN]": "KDE 视觉设计团队"
            }
        ],
        "Category": "",
        "Description": "Breeze by the KDE VDG",
        "Description[ar]": "نسيم من مجموعة تصميم كِيدِي",
        "Description[az]": "KDE VDG tərəfindən Breeze İş mühiti görünüşü",
        "Description[be]": "Breeze ад KDE VDG",
        "Description[bg]": "Breeze от KDE VDG",
        "Description[ca@valencia]": "Brisa, creat pel VDG de KDE",
        "Description[ca]": "Brisa, creat pel VDG del KDE",
        "Description[cs]": "Breeze od KDE VDG",
        "Description[de]": "Breeze von der KDE VDG",
        "Description[en_GB]": "Breeze by the KDE VDG",
        "Description[eo]": "Brizo de la KDE VDG",
        "Description[es]": "Brisa por KDE VDG",
        "Description[eu]": "Brisa KDEren VDGk egina",
        "Description[fi]": "Breeze KDE VDG:ltä",
        "Description[fr]": "Breeze par l'équipe « KDE VDG »",
        "Description[gl]": "Brisa do KDE VDG.",
        "Description[he]": "בריזה מאת קבוצת העיצוב החזותי של KDE",
        "Description[ia]": "Breeze (Brisa) per le KDE VDG",
        "Description[id]": "Breeze oleh KDE VDG",
        "Description[it]": "Brezza a cura del KDE VDG",
        "Description[ka]": "Breeze KDE VDG-სგან",
        "Description[ko]": "KDE 시각 디자인 그룹에서 제작한 Breeze",
        "Description[nl]": "Breeze door de KDE VDG",
        "Description[nn]": "Breeze frå KDE VDG",
        "Description[pl]": "Bryza autorstwa KDE VDG",
        "Description[pt]": "Brisa da VDG do KDE",
        "Description[pt_BR]": "Breeze pelo KDE VDG",
        "Description[ru]": "Оформление рабочей среды Breeze от KDE VDG",
        "Description[sa]": "KDE VDG द्वारा Breeze",
        "Description[sk]": "Vánok od KDE VDG",
        "Description[sl]": "Sapica od KDE VDG",
        "Description[sv]": "Breeze av KDE:s visuella designgrupp",
        "Description[ta]": "கே.டீ.யீ. VDG வழங்கும் பிரீஸ்",
        "Description[tr]": "KDE VDG tarafından Esinti",
        "Description[uk]": "Breeze, автори — KDE VDG",
        "Description[vi]": "Breeze, do KDE VDG",
        "Description[x-test]": "xxBreeze by the KDE VDGxx",
        "Description[zh_CN]": "Breeze 微风主题，由 KDE VDG (视觉设计团队) 设计制作",
        "EnabledByDefault": true,
        "Id": "default",
        "License": "LGPL",
        "Name": "Breeze",
        "Name[ar]": "نسيم",
        "Name[az]": "Breeze",
        "Name[be]": "Breeze",
        "Name[bg]": "Breeze",
        "Name[ca@valencia]": "Brisa",
        "Name[ca]": "Brisa",
        "Name[cs]": "Breeze",
        "Name[de]": "Breeze",
        "Name[en_GB]": "Breeze",
        "Name[eo]": "Vento",
        "Name[es]": "Brisa",
        "Name[eu]": "Brisa",
        "Name[fi]": "Breeze",
        "Name[fr]": "Breeze",
        "Name[gl]": "Brisa",
        "Name[he]": "בריזה",
        "Name[ia]": "Brisa",
        "Name[id]": "Breeze",
        "Name[it]": "Brezza",
        "Name[ka]": "ნიავი",
        "Name[ko]": "Breeze",
        "Name[nl]": "Breeze",
        "Name[nn]": "Breeze",
        "Name[pl]": "Bryza",
        "Name[pt]": "Brisa",
        "Name[pt_BR]": "Breeze",
        "Name[ru]": "Breeze",
        "Name[sa]": "Breeze",
        "Name[sk]": "Vánok",
        "Name[sl]": "Sapica",
        "Name[sv]": "Breeze",
        "Name[ta]": "பிரீஸ்",
        "Name[tr]": "Esinti",
        "Name[uk]": "Breeze",
        "Name[vi]": "Breeze",
        "Name[x-test]": "xxBreezexx",
        "Name[zh_CN]": "Breeze 微风",
        "Version": "@KF6_MIN_VERSION@",
        "Website": "https://plasma.kde.org"
    },
    "X-Plasma-API": "5.0"
}

==> plasma-framework-5.96.0.tar.xz: plasma-framework-5.96.0/src/desktoptheme/breeze/metadata.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "kde-artists@kde.org",
                "Name": "KDE Visual Design Group",
                "Name[az]": "KDE Vizual Dizayn Qrupu",
                "Name[bg]": "KDE Visual Design Group",
                "Name[ca@valencia]": "Grup de disseny visual de KDE",
                "Name[ca]": "Grup de disseny visual de KDE",
                "Name[en_GB]": "KDE Visual Design Group",
                "Name[es]": "El grupo de diseño visual de KDE",
                "Name[eu]": "KDE Diseinu bisualeko taldea",
                "Name[fi]": "KDE:n visuaalinen suunnitteluryhmä",
                "Name[fr]": "Groupe de conception graphique de KDE « VDG » (Visual Design Group)",
                "Name[ia]": "KDE Visual Design Group (Gruppo de Designo Visual de KDE)",
                "Name[id]": "Grup Desain Visual KDE",
                "Name[it]": "KDE Visual Design Group",
                "Name[ko]": "KDE 시각 디자인 그룹",
                "Name[nl]": "KDE Visuele ontwerpgroep",
                "Name[nn]": "KDE Visual Design Group",
                "Name[pl]": "Grupa oprawy graficznej KDE",
                "Name[pt]": "Grupo de Desenho Visual do KDE",
                "Name[ru]": "Группа KDE Visual Design",
                "Name[sl]": "Skupina vizualnega designa KDE",
                "Name[sv]": "KDE:s visuella designgrupp",
                "Name[tr]": "KDE Görsel Tasarım Grubu",
                "Name[uk]": "Група з візуального дизайну KDE",
                "Name[vi]": "Đội Thiết kế Trực quan KDE",
                "Name[x-test]": "xxKDE Visual Design Groupxx",
                "Name[zh_CN]": "KDE 视觉设计团队"
            }
        ],
        "Category": "",
        "Description": "Breeze by the KDE VDG",
        "Description[az]": "KDE VDG tərəfindən Breeze İş mühiti görünüşü",
        "Description[bg]": "Breeze от KDE VDG",
        "Description[ca@valencia]": "Brisa, creat pel VDG de KDE",
        "Description[ca]": "Brisa, creat pel VDG del KDE",
        "Description[en_GB]": "Breeze by the KDE VDG",
        "Description[es]": "Brisa por KDE VDG",
        "Description[eu]": "Brisa KDEren VDGk egina",
        "Description[fi]": "Breeze KDE VDG:ltä",
        "Description[fr]": "Breeze par l'équipe « KDE VDG »",
        "Description[ia]": "Breeze (Brisa) per le KDE VDG",
        "Description[id]": "Breeze oleh KDE VDG",
        "Description[it]": "Brezza a cura del KDE VDG",
        "Description[ko]": "KDE 시각 디자인 그룹에서 제작한 Breeze",
        "Description[nl]": "Breeze door de KDE VDG",
        "Description[nn]": "Breeze frå KDE VDG",
        "Description[pl]": "Bryza autorstwa KDE VDG",
        "Description[pt]": "Brisa da VDG do KDE",
        "Description[ru]": "Оформление рабочей среды Breeze от KDE VDG",
        "Description[sl]": "Sapica od KDE VDG",
        "Description[sv]": "Breeze av KDE:s visuella designgrupp",
        "Description[tr]": "KDE VDG tarafından Esinti",
        "Description[uk]": "Breeze, автори — KDE VDG",
        "Description[vi]": "Breeze, do KDE VDG",
        "Description[x-test]": "xxBreeze by the KDE VDGxx",
        "Description[zh_CN]": "Breeze 微风主题，由 KDE VDG (视觉设计团队) 设计制作",
        "EnabledByDefault": true,
        "Id": "default",
        "License": "LGPL",
        "Name": "Breeze",
        "Name[az]": "Breeze",
        "Name[bg]": "Breeze",
        "Name[ca@valencia]": "Brisa",
        "Name[ca]": "Brisa",
        "Name[cs]": "Breeze",
        "Name[en_GB]": "Breeze",
        "Name[es]": "Brisa",
        "Name[eu]": "Brisa",
        "Name[fi]": "Breeze",
        "Name[fr]": "Breeze",
        "Name[ia]": "Brisa",
        "Name[id]": "Breeze",
        "Name[it]": "Brezza",
        "Name[ko]": "Breeze",
        "Name[nl]": "Breeze",
        "Name[nn]": "Breeze",
        "Name[pl]": "Bryza",
        "Name[pt]": "Brisa",
        "Name[ru]": "Breeze",
        "Name[sl]": "Sapica",
        "Name[sv]": "Breeze",
        "Name[tr]": "Esinti",
        "Name[uk]": "Breeze",
        "Name[vi]": "Breeze",
        "Name[x-test]": "xxBreezexx",
        "Name[zh_CN]": "Breeze 微风",
        "Version": "@KF_VERSION@",
        "Website": "https://plasma.kde.org"
    },
    "X-Plasma-API": "5.0"
}
